@@ -4,7 +4,9 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
+![Stability: Deprecated](https://img.shields.io/badge/STABILITY-DEPRECATED-red?style=for-the-badge)
+
+> Some of our early constructs don’t meet the naming standards that evolved for the library. We are releasing completely feature compatible versions with corrected names. The underlying implementation code is the same regardless of whether you deploy the construct using the old or new name. We will support both names for all 1.x releases, but in 2.x we will only publish the correctly named constructs.
 
 > All classes are under active development and subject to non-backward compatible changes or removal in any
 > future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
@@ -72,7 +74,7 @@ new EventsRuleToStepFunction(scope: Construct, id: string, props: EventsRuleToSt
 |:-------------|:----------------|-----------------|
 |eventsRule|[`events.Rule`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.Rule.html)|Returns an instance of events.Rule created by the construct|
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of sfn.StateMachine created by the construct|
-|stateMachineLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for StateMachine|
+|stateMachineLogGroup|[`logs.ILogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.ILogGroup.html)|Returns an instance of the ILogGroup created by the construct for StateMachine|
 |cloudwatchAlarms?|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 
 ## Default settings
@@ -140,7 +142,6 @@ class EventsRuleToStepFunction(
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
-        :since: 0.9.0
         :summary: Constructs a new instance of the EventsRuleToStepFunction class.
         '''
         props = EventsRuleToStepFunctionProps(
@@ -164,8 +165,8 @@ class EventsRuleToStepFunction(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="stateMachineLogGroup")
-    def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "stateMachineLogGroup"))
+    def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
+        return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
